StandardTextListBlock : The A+ Content standard fixed length list of text, usually presented as bullet points.
Fields
text_list: Vec<TextItem>Implementations
sourceimpl StandardTextListBlock
impl StandardTextListBlock
sourcepub fn new(text_list: Vec<TextItem>) -> StandardTextListBlock
pub fn new(text_list: Vec<TextItem>) -> StandardTextListBlock
The A+ Content standard fixed length list of text, usually presented as bullet points.